@@ -5,6 +5,8 @@ from asynciorm.base.fields import (
     BaseTextField,
     BaseBooleanField,
     BaseDateTimeField,
+    BaseDateField,
+    BaseTimeField,
     BaseForeignKeyField,
     BaseFloatField,
 )
@@ -49,6 +51,18 @@ class DateTimeField(BaseDateTimeField):
     def _datatype(self):
         return ' VARCHAR(255) '
 
+class TimeField(BaseTimeField):
+
+    @property
+    def _datatype(self):
+        return ' VARCHAR(255) '
+
+class DateField(BaseDateField):
+    
+    @property
+    def _datatype(self):
+        return ' VARCHAR(255) '
+
 
 class ForeignKeyField(BaseForeignKeyField):
 
